@@ -1,6 +1,9 @@
 package App::Midgen;
 
 use 5.008001;
+use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3, TRUE => 1,
+	FALSE => 0,};
+
 use Moo;
 with qw(
 	App::Midgen::Role::Options
@@ -13,22 +16,23 @@ with qw(
 	App::Midgen::Role::FindMinVersion
 	App::Midgen::Role::Output
 	App::Midgen::Role::UseModule
+	App::Midgen::Role::Experimental
+	App::Midgen::Role::Heuristics
 );
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 use version;
-our $VERSION = '0.29_11';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.31_05';
+$VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
-use Cwd qw(cwd);
+use Cwd qw(getcwd);
 use Data::Printer {caller_info => 1, colored => 1,};
 use File::Find qw(find);
 use File::Spec;
-use List::MoreUtils qw(firstidx);
 use MetaCPAN::API;
 use Module::CoreList;
 use PPI;
@@ -36,11 +40,10 @@ use Perl::PrereqScanner;
 use Term::ANSIColor qw( :constants colored colorstrip );
 use Try::Tiny;
 use Tie::Static qw(static);
-use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3, TRUE => 1, FALSE => 0,};
 use version;
 
 # stop rlib from Fing all over cwd
-our $Working_Dir = cwd();
+our $Working_Dir = getcwd();
 our $Min_Version = 0;
 
 
@@ -55,28 +58,32 @@ sub run {
 		$self->first_package_name();
 	};
 
-	$self->find_required_modules();
 
-#	p $self->{modules} if ($self->verbose == TWO);
-
-	$self->find_required_test_modules();
+	$self->find_runtime_modules();
+	$self->find_test_modules();
+	$self->find_develop_modules() if $self->experimental;
 
+	#now for some Heuristics :)
+	$self->recast_to_runtimerequires($self->{RuntimeRequires},
+		$self->{RuntimeRecommends});
+	$self->recast_to_testrequires($self->{TestRequires}, $self->{TestSuggests});
 
 	# Now we have switched to MetaCPAN-Api we can hunt for noisy children in tests
 	if ($self->experimental) {
 
-		$self->remove_noisy_children($self->{package_requires});
-		$self->remove_twins($self->{package_requires});
+		$self->remove_noisy_children($self->{RuntimeRequires});
+		$self->remove_twins($self->{RuntimeRequires});
 
 		# Run a second time if we found any twins, this will sort out twins and triplets etc
-		$self->remove_noisy_children($self->{package_requires}) if $self->found_twins;
+		$self->remove_noisy_children($self->{RuntimeRequires})
+			if $self->found_twins;
 
-		foreach (qw( test_requires recommends test_develop )) {
+		foreach (qw( TestRequires TestSuggests DevelopRequires )) {
 
 			p $self->{$_} if $self->debug;
 			$self->remove_noisy_children($self->{$_});
 			foreach my $module (keys %{$self->{$_}}) {
-				if ($self->{package_requires}{$module}) {
+				if ($self->{RuntimeRequires}{$module}) {
 					warn $module if $self->debug;
 					try {
 						delete $self->{$_}{$module};
@@ -87,23 +94,37 @@ sub run {
 		}
 	}
 
-
 	# display chosen output format
 	$self->output_header();
+	$self->output_main_body('RuntimeRequires',   $self->{RuntimeRequires});
+	$self->output_main_body('RuntimeRecommends', $self->{RuntimeRecommends})
+		if $self->meta2;
+	$self->output_main_body('TestRequires', $self->{TestRequires});
+	if ($self->meta2) {
+		$self->output_main_body('TestSuggests', $self->{TestSuggests});
+		$self->output_main_body('Close', {});
+		$self->output_main_body('DevelopRequires', $self->{DevelopRequires});
+	}
+	else {
 
-	$self->output_main_body('requires',      $self->{package_requires});
-			if ($self->format =~ /cpanfile|metajson|dist/) {
-				$self->output_main_body('runtime_recommends', $self->{runtime_recommends});
-			}
-
-	$self->output_main_body('test_requires', $self->{test_requires});
-	$self->output_main_body('recommends',    $self->{recommends});
-	$self->output_main_body('test_develop',  $self->{test_develop})
-		if $self->develop;
+		# concatenate hashes
+		try {
+			%{$self->{recommends}} = (%{$self->{RuntimeRecommends}},);
+		};
+		try {
+			%{$self->{recommends}}
+				= (%{$self->{recommends}}, %{$self->{TestSuggests}},);
+		};
+		try {
+			%{$self->{recommends}}
+				= (%{$self->{recommends}}, %{$self->{DevelopRequires}},);
+		};
+		$self->output_main_body('recommends', $self->{recommends});
+	}
 
 	$self->output_footer();
 
-	p $self->{modules} if $self->debug;
+	p $self->{modules} if ($self->verbose == TWO);
 
 	return;
 }
@@ -114,7 +135,7 @@ sub run {
 sub _initialise {
 	my $self = shift;
 
-# let's give Output a copy, to stop it being F'up as well, suspect Tiny::Path as-well rlib
+	# let's give Output a copy, to stop it being F'up as well, suspect Tiny::Path as-well rlib
 	warn 'working in dir: ' . $Working_Dir if $self->debug;
 
 	return;
@@ -129,7 +150,7 @@ sub first_package_name {
 	try {
 		find(
 			sub { _find_package_names($self); },
-			File::Spec->catfile($Working_Dir, 'lib' )
+			File::Spec->catfile($Working_Dir, 'lib')
 		);
 	};
 
@@ -148,7 +169,7 @@ sub first_package_name {
 	};
 
 	# I still want to see package name even though infile sets verbose = 0
-	print 'Package: '. $self->distribution_name ."\n"
+	print 'Package: ' . $self->distribution_name . "\n"
 		if $self->verbose
 		or $self->format eq 'infile';
 
@@ -160,7 +181,7 @@ sub first_package_name {
 sub _find_package_names {
 	my $self     = shift;
 	my $filename = $_;
-	static \ my $files_checked;
+	static \my $files_checked;
 	if (defined $files_checked) {
 		return if $files_checked >= THREE;
 	}
@@ -181,13 +202,14 @@ sub _find_package_names {
 
 
 #######
-# find_required_modules
+# find_runtime_modules
 #######
-sub find_required_modules {
+sub find_runtime_modules {
 	my $self = shift;
 
 	my @posiable_directories_to_search
-		= map { File::Spec->catfile($Working_Dir, $_) } qw( bin share script lib );
+		= map { File::Spec->catfile($Working_Dir, $_) }
+		qw( bin share script lib );
 
 	my @directories_to_search = ();
 	foreach my $directory (@posiable_directories_to_search) {
@@ -198,53 +220,18 @@ sub find_required_modules {
 	p @directories_to_search if $self->debug;
 
 	try {
-		find(sub { _find_makefile_requires($self); }, @directories_to_search);
+		find(sub { _find_runtime_requirments($self); }, @directories_to_search);
 	};
 
 	return;
 
 }
 #######
-# find_required_modules
+# _find_runtime_requirments
 #######
-sub find_required_test_modules {
-	my $self = shift;
-
-	# By default we shell only check t\ (to xt\ or not?)
-	my @posiable_directories_to_search;
-	if (not $self->experimental) {
-		@posiable_directories_to_search
-			= map { File::Spec->catfile($Working_Dir, $_) } qw( t );
-	}
-	else {
-		@posiable_directories_to_search
-			= map { File::Spec->catfile($Working_Dir, $_) } qw( t xt );
-	}
-
-	my @directories_to_search = ();
-	foreach my $directory (@posiable_directories_to_search) {
-		if (defined -d $directory) {
-			push @directories_to_search, $directory;
-		}
-	}
-
-	try {
-		foreach my $directorie (@directories_to_search) {
-			find(sub { _find_makefile_test_requires($self, $directorie); },
-				$directorie);
-		}
-	};
-
-	return;
-
-}
-
-#######
-# _find_makefile_requires
-#######
-sub _find_makefile_requires {
-	my $self      = shift;
-	my $filename  = $_;
+sub _find_runtime_requirments {
+	my $self     = shift;
+	my $filename = $_;
 
 	return if $self->is_perlfile($filename) eq FALSE;
 
@@ -253,17 +240,19 @@ sub _find_makefile_requires {
 	$self->_set_looking_infile(File::Spec->catfile($relative_dir, $filename));
 	$self->_set_ppi_document(PPI::Document->new($filename));
 
-	$self->min_version();
-
 	# do extra test early check for use_module before hand
-	$self->xtests_use_module('runtime_recommends');
+	$self->xtests_use_module('RuntimeRecommends');
 
 	# ToDo add eval/try here -> prereqs { runtime { suggests or recommends {...}}}
-	$self->xtests_eval('runtime_recommends');
+	$self->xtests_eval('RuntimeRecommends');
 
+	# normal pps -> RuntimeRequires
 	my $prereqs = $self->scanner->scan_ppi_document($self->ppi_document);
 	my @modules = $prereqs->required_modules;
 
+	#run pmv now
+	$self->min_version(	$self->looking_infile ) if $self->format ne 'infile';
+
 	foreach my $mod_ver (@modules) {
 		$self->{found_version}{$mod_ver}
 			= $prereqs->requirements_for_module($mod_ver);
@@ -271,7 +260,7 @@ sub _find_makefile_requires {
 
 	$self->{skip_not_mcpan_stamp} = 0;
 
-	if ( grep { $_ =~ m/^Dist::Zilla::Role::PluginBundle/ } @modules ) {
+	if (grep { $_ =~ m/^Dist::Zilla::Role::PluginBundle/ } @modules) {
 
 		$self->{skip_not_mcpan_stamp} = 1;
 
@@ -294,23 +283,59 @@ sub _find_makefile_requires {
 		}
 	}
 
-	$self->_process_found_modules('package_requires', \@modules);
+	$self->_process_found_modules('RuntimeRequires', \@modules,
+		'Perl::PrereqScanner', 'RuntimeRequires',);
 	return;
 }
 
 
 #######
-# _find_makefile_test_requires
+# find_test_modules
 #######
-sub _find_makefile_test_requires {
+sub find_test_modules {
+	my $self = shift;
+
+	my $directory = 't';
+	if (defined -d $directory) {
+
+		find(sub { _find_test_develop_requirments($self, $directory); },
+			$directory);
+
+	}
+
+	return;
+
+}
+#######
+# find_develop_modules
+#######
+sub find_develop_modules {
+	my $self = shift;
+
+	my $directory = 'xt';
+	if (defined -d $directory) {
+
+		find(sub { _find_test_develop_requirments($self, $directory); },
+			$directory);
+
+	}
+	return;
+
+}
+
+
+#######
+# _find_test_develop_requirments 
+#######
+sub _find_test_develop_requirments {
 	my $self       = shift;
 	my $directorie = shift;
-	my $filename = $_;
+	my $filename   = $_;
 
 	##p $directorie;
-	my $prerequisites
-		= ($directorie =~ m/xt$/) ? 'test_develop' : 'test_requires';
-	$self->_set_xtest('test_develop') if $directorie =~ m/xt$/;
+	my $phase_relationship
+		= ($directorie =~ m/xt$/) ? 'DevelopRequires' : 'TestSuggests';
+	$self->_set_xtest(TRUE) if $directorie =~ m/xt$/;
 
 	return if $self->is_perlfile($filename) eq FALSE;
 
@@ -318,23 +343,27 @@ sub _find_makefile_test_requires {
 	$relative_dir =~ s/$Working_Dir//;
 	$self->_set_looking_infile(File::Spec->catfile($relative_dir, $filename));
 
-	$self->min_version() if not $self->experimental;
-
 	# Load a Document from a file and check use and require contents
 	$self->_set_ppi_document(PPI::Document->new($filename));
 
+	# don't scan xt/ for pmv
+	$self->min_version($filename) if $directorie !~ m/xt$/ or $self->format ne 'infile';
+
+
 	# do extra test early check for Test::Requires before hand
-	$self->xtests_test_requires();
+	$self->xtests_test_requires($phase_relationship);
 
 	# do extra test early check for use_ok in BEGIN blocks before hand
-	$self->xtests_use_ok();
+	$self->xtests_use_ok($phase_relationship);
 
 	# do extra test early to identify eval before hand
-	$self->xtests_eval('test_requires');
+	$self->xtests_eval($phase_relationship);
 
 	# do extra test early check for use_module before hand
-	$self->xtests_use_module('test_requires');
+	$self->xtests_use_module($phase_relationship);
 
+
+	# let's run p-ps for the rest
 	my $prereqs = $self->scanner->scan_ppi_document($self->ppi_document);
 	my @modules = $prereqs->required_modules;
 
@@ -346,17 +375,19 @@ sub _find_makefile_test_requires {
 	}
 
 	if (scalar @modules > 0) {
-		if ($self->format =~ /cpanfile|metajson|dist/) {
-			if ($self->xtest eq 'test_requires') {
-				$self->_process_found_modules('test_requires', \@modules);
-			}
-			elsif ($self->develop && $self->xtest eq 'test_develop') {
-				$self->_process_found_modules('test_develop', \@modules);
-			}
+		if ($self->xtest) {
+			$self->_process_found_modules($phase_relationship, \@modules,
+				'Perl::PrereqScanner', $phase_relationship,)
+				if $self->meta2;
+			$self->_process_found_modules('DevelopRequires', \@modules,
+				'Perl::PrereqScanner', 'DevelopRequires',)
+				if not $self->meta2;
 		}
 		else {
-			$self->_process_found_modules('test_requires', \@modules);
+			$self->_process_found_modules('TestRequires', \@modules,
+				'Perl::PrereqScanner', 'TestRequires',);
 		}
+
 	}
 
 	return;
@@ -367,9 +398,11 @@ sub _find_makefile_test_requires {
 # composed method - _process_found_modules
 #######
 sub _process_found_modules {
-	my $self         = shift;
-	my $require_type = shift;
-	my $modules_ref  = shift;
+	my $self          = shift;
+	my $require_type  = shift;
+	my $modules_ref   = shift;
+	my $extra_scanner = shift || 'none';
+	my $pr_location = shift || 'none';
 
 	foreach my $module (@{$modules_ref}) {
 
@@ -384,50 +417,58 @@ sub _process_found_modules {
 
 			my $distribution_name = $self->distribution_name || 'm/t';
 
-				if ( $module =~ /perl/sxm) {
+			if ($module =~ /perl/sxm) {
 
-					# ignore perl we will get it from minperl required
-					next;
-				}
-				elsif ( $module =~ /\A\Q$distribution_name\E/sxm) {
+				# ignore perl we will get it from minperl required
+				next;
+			}
+			elsif ($module =~ /\A\Q$distribution_name\E/sxm) {
 
-					# don't include our own packages here
-					next;
-				}
-				elsif ( $module =~ /^t::/sxm) {
+				# don't include our own packages here
+				next;
+			}
+			elsif ($module =~ /^t::/sxm) {
 
-					# don't include our own test packages here
-					next;
-				}
+				# don't include our own test packages here
+				next;
+			}
+			elsif ($module =~ /^inc::Module::Install/sxm) {
 
-				elsif ( $module =~ /Mojo/sxm) {
-					if ($self->experimental) {
-						if ($self->_check_mojo_core($module, $require_type)) {
-							if (not $self->quiet) {
-								print BRIGHT_BLACK;
-								print "swapping out $module for Mojolicious\n";
-								print CLEAR;
-							}
-							next;
+				# don't inc::Module::Install as it is really Module::Install
+				next;
+			}
+			elsif ($module =~ /Mojo/sxm) {
+				if ($self->experimental) {
+					if ($self->_check_mojo_core($module, $require_type)) {
+						if (not $self->quiet) {
+							print BRIGHT_BLACK;
+							print "swapping out $module for Mojolicious\n";
+							print CLEAR;
 						}
+						next;
 					}
 				}
-				elsif ( $module =~ /^Padre/sxm) {
+			}
+			elsif ($module =~ /^Padre/sxm) {
 
-					# mark all Padre core as just Padre only, for plugins
-					$module = 'Padre';
-				}
+				# mark all Padre core as just Padre only, for plugins
+				$module = 'Padre';
+			}
 		}
 
 		# lets keep track of how many times a module include is found
 		$self->{modules}{$module}{count} += 1;
+
 		push @{$self->{modules}{$module}{infiles}},
-			[$self->looking_infile(), $self->{found_version}{$module} || 0];
+			[
+			$self->looking_infile(), $self->{found_version}{$module} || 0,
+			$extra_scanner, $pr_location,
+			];
 
 		# don't process already found modules
-		p $self->{modules}{$module}{location} if $self->debug;
+		p $self->{modules}{$module}{prereqs} if $self->debug;
 
-		next if defined $self->{modules}{$module}{location};
+		next if defined $self->{modules}{$module}{prereqs};
 		p $module if $self->debug;
 
 		# add skip for infile as we don't need to get v-string from metacpan-api
@@ -450,42 +491,42 @@ sub _store_modules {
 		if not defined $self->{modules}{$module}{corelist};
 	my $version = $self->get_module_version($module, $require_type);
 
-		if ( $version eq '!mcpan') {
-			$self->{$require_type}{$module} = colored('!mcpan', 'magenta')
-				if not $self->{skip_not_mcpan_stamp};
-			$self->{modules}{$module}{location} = $require_type;
-			$self->{modules}{$module}{version}  = '!mcpan';
-		}
-		elsif ( $version eq 'core') {
-			$self->{$require_type}{$module} = $version if $self->core;
-			$self->{$require_type}{$module} = '0'      if $self->zero;
-			$self->{modules}{$module}{location} = $require_type;
-			$self->{modules}{$module}{version} = $version if $self->core;
+	if ($version eq '!mcpan') {
+		$self->{$require_type}{$module} = colored('!mcpan', 'magenta')
+			if not $self->{skip_not_mcpan_stamp};
+		$self->{modules}{$module}{prereqs} = $require_type;
+		$self->{modules}{$module}{version} = '!mcpan';
+	}
+	elsif ($version eq 'core') {
+		$self->{$require_type}{$module} = $version if $self->core;
+		$self->{$require_type}{$module} = '0'      if $self->zero;
+		$self->{modules}{$module}{prereqs} = $require_type;
+		$self->{modules}{$module}{version} = $version if $self->core;
+	}
+	else {
+		if ($self->{modules}{$module}{corelist}) {
+
+			$self->{$require_type}{$module} = colored($version, 'bright_yellow')
+				if ($self->dual_life || $self->core);
+			$self->{modules}{$module}{prereqs} = $require_type
+				if ($self->dual_life || $self->core);
+			$self->{modules}{$module}{version} = $version
+				if ($self->dual_life || $self->core);
+			$self->{modules}{$module}{dual_life} = 1;
 		}
 		else {
-			if ($self->{modules}{$module}{corelist}) {
+			$self->{$require_type}{$module} = colored($version, 'yellow');
+			$self->{$require_type}{$module}
+				= colored(version->parse($version)->numify, 'yellow')
+				if $self->numify;
 
-				$self->{$require_type}{$module} = colored($version, 'bright_yellow')
-					if ($self->dual_life || $self->core);
-				$self->{modules}{$module}{location} = $require_type
-					if ($self->dual_life || $self->core);
-				$self->{modules}{$module}{version} = $version
-					if ($self->dual_life || $self->core);
-				$self->{modules}{$module}{dual_life} = 1;
-			}
-			else {
-				$self->{$require_type}{$module} = colored($version, 'yellow');
-				$self->{$require_type}{$module}
-					= colored(version->parse($version)->numify, 'yellow')
-					if $self->numify;
+			$self->{modules}{$module}{prereqs} = $require_type;
+			$self->{modules}{$module}{version} = $version;
 
-				$self->{modules}{$module}{location} = $require_type;
-				$self->{modules}{$module}{version}  = $version;
-
-				$self->{$require_type}{$module} = colored($version, 'bright_cyan')
-					if $self->{modules}{$module}{'distribution'};
-			}
+			$self->{$require_type}{$module} = colored($version, 'bright_cyan')
+				if $self->{modules}{$module}{'distribution'};
 		}
+	}
 	p $self->{modules}{$module} if $self->debug;
 
 	return;
@@ -518,168 +559,6 @@ sub _in_corelist {
 	return 0;
 }
 
-#######
-# remove_noisy_children
-#######
-sub remove_noisy_children {
-	my $self = shift;
-	my $required_ref = shift || return;
-	my @sorted_modules;
-
-	foreach my $module_name (sort keys %{$required_ref}) {
-		push @sorted_modules, $module_name;
-	}
-
-	p @sorted_modules if $self->debug;
-
-	foreach my $parent_name (@sorted_modules) {
-		my $outer_index = firstidx { $_ eq $parent_name } @sorted_modules;
-
-		# inc so we don't end up with parent eq child
-		$outer_index++;
-		foreach my $inner_index ($outer_index .. $#sorted_modules) {
-			my $child_name = $sorted_modules[$inner_index];
-
-			# we just caught an undef
-			next if not defined $child_name;
-			if ($child_name =~ /^ $parent_name ::/x) {
-
-				my $valied_seperation = 1;
-
-				# as we only do this against -x, why not be extra vigilant
-				$valied_seperation = THREE
-					if $parent_name =~ /^Dist::Zilla|Moose|MooseX|Moo|Mouse/;
-
-				# Checking for one degree of separation
-				# ie A::B -> A::B::C is ok but A::B::C::D is not
-				if ($self->degree_separation($parent_name, $child_name)
-					<= $valied_seperation)
-				{
-
-					# Test for same version number
-					if (colorstrip($required_ref->{$parent_name}) eq
-						colorstrip($required_ref->{$child_name}))
-					{
-						if (not $self->quiet) {
-							if ($self->verbose) {
-								print BRIGHT_BLACK;
-								print 'delete miscreant noisy child '
-									. $child_name . ' => '
-									. $required_ref->{$child_name};
-								print CLEAR. "\n";
-							}
-						}
-						try {
-							delete $required_ref->{$child_name};
-							splice @sorted_modules, $inner_index, 1;
-
-							unless ($self->{modules}{$parent_name}) {
-								$self->{modules}{$parent_name}{location} = 'expermental';
-								$self->{modules}{$parent_name}{version}
-									= $required_ref->{$parent_name};
-								$self->{modules}{$parent_name}{count} += 1;
-							}
-						};
-						p @sorted_modules if $self->debug;
-
-						# we need to redo as we just deleted a child
-						redo;
-
-					}
-					else {
-
-						# not my child so lets try the next one
-						next;
-					}
-				}
-			}
-			else {
-
-				# no more like the parent so lets start again
-				last;
-			}
-		}
-	}
-	return;
-}
-
-#######
-# remove_twins
-#######
-sub remove_twins {
-	my $self = shift;
-	my $required_ref = shift || return;
-	my @sorted_modules;
-	foreach my $module_name (sort keys %{$required_ref}) {
-		push @sorted_modules, $module_name;
-	}
-
-	p @sorted_modules if $self->debug;
-
-	# exit if only 1 Module found
-	return if $#sorted_modules == 0;
-
-	my $n = 0;
-	while ($sorted_modules[$n]) {
-
-		my $dum_name    = $sorted_modules[$n];
-		my $dum_parient = $dum_name;
-		$dum_parient =~ s/(::\w+)$//;
-
-		my $dee_parient;
-		my $dee_name;
-		if (($n + 1) <= $#sorted_modules) {
-			$n++;
-			$dee_name    = $sorted_modules[$n];
-			$dee_parient = $dee_name;
-			$dee_parient =~ s/(::\w+)$//;
-		}
-
-		# Checking for same patient and score
-		if ( $dum_parient eq $dee_parient
-			&& $self->degree_separation($dum_name, $dee_name) == 0)
-		{
-
-			# Test for same version number
-			if ($required_ref->{$sorted_modules[$n - 1]} eq
-				$required_ref->{$sorted_modules[$n]})
-			{
-				if (not $self->quiet) {
-					if ($self->verbose) {
-						print BRIGHT_BLACK;
-
-						# stdout - 'i have found twins';
-						print $dum_name . ' => '
-							. $required_ref->{$sorted_modules[$n - 1]};
-						print BRIGHT_BLACK ' <-twins-> '
-							. $dee_name . ' => '
-							. $required_ref->{$sorted_modules[$n]};
-						print CLEAR "\n";
-					}
-				}
-
-				#Check for vailed parent
-				my $version;
-
-				$version = $self->get_module_version($dum_parient);
-
-				if ( version::is_lax($version) ) {
-					#Check parent version against a twins version
-					if ($version eq $required_ref->{$sorted_modules[$n]}) {
-						print $dum_parient . ' -> '
-							. $version
-							. " is the parent of these twins\n"
-							if $self->verbose;
-						$required_ref->{$dum_parient} = $version;
-						$self->_set_found_twins(1);
-					}
-				}
-			}
-		}
-		$n++ if ($n == $#sorted_modules);
-	}
-	return;
-}
 
 #######
 # _check_mojo_core
@@ -691,7 +570,7 @@ sub _check_mojo_core {
 
 
 	my $mojo_module_ver;
-	static \ my $mojo_ver;
+	static \my $mojo_ver;
 
 	if (not defined $mojo_ver) {
 		$mojo_ver = $self->get_module_version('Mojolicious');
@@ -712,7 +591,7 @@ sub _check_mojo_core {
 		$self->{$require_type}{'Mojolicious'}
 			= colored($mojo_module_ver, 'bright_blue')
 			if !$self->{modules}{'Mojolicious'};
-		$self->{modules}{'Mojolicious'}{location} = $require_type;
+		$self->{modules}{'Mojolicious'}{prereqs} = $require_type;
 		return 1;
 	}
 	else {
@@ -735,7 +614,7 @@ sub get_module_version {
 	try {
 		$module =~ s/::/-/g;
 
-# quick n dirty, get version number if module is classed as a distribution in metacpan
+		# quick n dirty, get version number if module is classed as a distribution in metacpan
 		my $mod = $self->mcpan->release(distribution => $module);
 
 		#p $mod;
@@ -784,8 +663,7 @@ sub get_module_version {
 		print BRIGHT_BLACK;
 		print $module
 			. ' Unique Release Sequence Indicator NOT! -> '
-			. $cpan_version
-			. "\n"
+			. $cpan_version . "\n"
 			if $self->verbose >= 1;
 		print CLEAR;
 		$cpan_version = version->parse($cpan_version)->numify;
@@ -815,35 +693,16 @@ sub mod_in_dist {
 		if ($self->experimental) {
 
 			$self->{$require_type}{$dist} = colored($version, 'bright_cyan')
-				if not defined $self->{modules}{$module}{location};
+				if not defined $self->{modules}{$module}{prereqs};
 		}
 
 		$self->{$require_type}{$module} = colored($version, 'bright_cyan')
-			if not defined $self->{modules}{$module}{location};
+			if not defined $self->{modules}{$module}{prereqs};
 	}
 
 	return;
 }
 
-#######
-# composed method degree of separation
-# parent A::B - child A::B::C
-#######
-sub degree_separation {
-	my $self   = shift;
-	my $parent = shift;
-	my $child  = shift;
-
-	# Use of implicit split to @_ is deprecated
-	my $parent_score = @{[split /::/, $parent]};
-	my $child_score  = @{[split /::/, $child]};
-	warn 'parent - ' . $parent . ' score - ' . $parent_score if $self->debug;
-	warn 'child - ' . $child . ' score - ' . $child_score    if $self->debug;
-
-	# switch around for a positive number
-	return $child_score - $parent_score;
-}
-
 
 no Moo;
 
@@ -857,11 +716,11 @@ __END__
 
 =head1 NAME
 
-App::Midgen - Check B<requires> & B<test_requires> of your package for CPAN inclusion.
+App::Midgen - Check B<RuntimeRequires> & B<TestRequires> of your package for CPAN inclusion.
 
 =head1 VERSION
 
-This document describes App::Midgen version: 0.29_11
+This document describes App::Midgen version: 0.31_05
 
 =head1 SYNOPSIS
 
@@ -915,18 +774,20 @@ For more info and sample output see L<wiki|https://github.com/kevindawson/App-Mi
 
 =over 4
 
-=item * degree_separation
+=item * find_runtime_modules
 
-now a separate Method, returns an integer.
+Search for C<Prereqs RuntimeRecommends> and C<Prereqs RuntimeRequires> in
+package modules C<script\>, C<bin\>, C<lib\>, C<share\> with B<UseModule>
+and B<Eval> followed by B<PPS>.
 
-=item * find_required_modules
+=item * find_test_modules
 
-Search for Includes B<use> and B<require> in package modules
+Search for C<Prereqs TestSuggests> and C<Prereqs TestRequire> in B<t\> scripts,
+with B<UseOk> and B<TestRequires> followed by B<PPS>.
 
-=item * find_required_test_modules
+=item * find_develop_modules
 
-Search for Includes B<use> and B<require> in test scripts,
-also B<use_ok>, I<plus some other patterns along the way.>
+Search for C<Prereqs DevelopRequire> in C<xt\> using all available scanners.
 
 =item * first_package_name
 
@@ -940,16 +801,6 @@ side affect of re-factoring, helps with code readability
 
 Check if module is in a distribution and use that version number, rather than 'undef'
 
-=item * remove_noisy_children
-
-Parent A::B has noisy Children A::B::C and A::B::D all with same version number.
-
-=item * remove_twins
-
-Twins E::F::G and E::F::H  have a parent E::F with same version number,
- so we add a parent E::F and re-test for noisy children,
- catching triplets along the way.
-
 =item * run
 
 =back
@@ -1022,7 +873,7 @@ it under the same terms as Perl 5 itself.
 =head1 SEE ALSO
 
 L<Perl::PrereqScanner>,
-L<Module::Install::DSL>
+L<inc::Module::Install::DSL>
 
 =head1 DISCLAIMER OF WARRANTY
 
