@@ -1,5 +1,7 @@
 package App::Midgen::Role::Attributes;
 
+use constant {TRUE => 1, FALSE => 0,};
+
 use Types::Standard qw( ArrayRef Bool Int Object Str);
 use Moo::Role;
 requires qw( experimental format );
@@ -9,7 +11,7 @@ requires qw( experimental format );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_11';
+our $VERSION = '0.31_05';
 $VERSION = eval $VERSION; ## no critic
 
 use Carp;
@@ -50,6 +52,23 @@ has 'found_twins' => (
 	},
 );
 
+has 'meta2' => (
+	is      => 'ro',
+	isa     => Bool,
+	lazy    => 1,
+	builder => '_meta2',
+);
+
+sub _meta2 {
+	my $self = shift;
+
+	if ( $self->format =~ m/cpanfile|metajson|dist/ ) {
+		return 1;
+	} else {
+		return 0;
+	}
+}
+
 has 'numify' => (
 	is      => 'ro',
 	isa     => Bool,
@@ -64,6 +83,13 @@ has 'package_names' => (
 	lazy    => 1,
 );
 
+has 'phase_relationship' => (
+	is      => 'rwp',
+	isa     => Str,
+	lazy    => 1,
+	default => sub { },
+);
+
 has 'ppi_document' => (
 	is   => 'rwp',
 	isa  => Object,
@@ -72,10 +98,10 @@ has 'ppi_document' => (
 
 has 'xtest' => (
 	is      => 'rwp',
-	isa     => Str,
+	isa     => Bool,
 	lazy    => 1,
 	default => sub {
-		'test_requires';
+	return FALSE;
 	},
 );
 
@@ -102,7 +128,7 @@ App::Midgen::Role::Attributes - Package Attributes used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_11
+version: 0.31_05
 
 =head1 METHODS
 
