@@ -1,23 +1,35 @@
 package App::Midgen::Role::FindMinVersion;
 
-use constant {TWO => 2,};
+use constant {TWO => 2, TRUE => 1, FALSE => 0,};
 
 use Types::Standard qw( Bool );
 use Moo::Role;
-requires qw( ppi_document debug );
+requires qw( ppi_document debug experimental verbose );
 
-our $VERSION = '0.29_11';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.31_05';
+$VERSION = eval $VERSION;    ## no critic
 
 use Perl::MinimumVersion;
 use Try::Tiny;
+use Term::ANSIColor qw( :constants colored colorstrip );
 use version;
+use Data::Printer {caller_info => 1, colored => 1,};
+
+has 'mro_skip' => (
+	is => 'rwp',
+	isa => Bool,
+	lazy => 1,
+	default => sub { 0; },
+);
+
 
 #######
-# find min perl version
+# find min perl version - pmv
 ######
 sub min_version {
-	my $self = shift;
+	my $self     = shift;
+	my $filename = shift;
+	$filename =~ s{^/}{};
 
 	my $dist_min_ver = $App::Midgen::Min_Version;
 	my $object;
@@ -51,9 +63,51 @@ sub min_version {
 			: version->parse($object->minimum_syntax_version);
 	};
 
-	print "min_version - $dist_min_ver\n" if ($self->verbose == TWO);
+	try {
+		my $blame = $object->minimum_syntax_reason->element->content;
+
+		if ($blame =~ m/\bmro[\s|;]/) {
+			$self->_set_mro_skip(TRUE);
+			print BRIGHT_BLACK
+				. 'Info: PMV blame = '
+#				. WHITE
+				. $blame
+#				. BRIGHT_BLACK
+				. ' -> 5.010 in '
+				. $filename
+#				. ' # -x to skip'
+				. CLEAR . "\n";
+		}
+	};
+
+#	if ($self->{mro_skip} && $self->{experimental}) {
+	if ($self->{mro_skip}) {
+
+		if (defined $self->{modules}{'MRO::Compat'}) {
+			foreach my $index (0 .. $#{$self->{modules}{'MRO::Compat'}{infiles}}) {
+				if ($self->{modules}{'MRO::Compat'}{infiles}->[$index][0] eq '/'
+					. $filename)
+				{
+					print BRIGHT_BLACK
+						. 'Warning: '
+						. WHITE . 'mro'
+						. BRIGHT_BLACK . ' & '
+						. WHITE
+						. 'MRO::Compat'
+						. BRIGHT_BLACK
+						. ' in the same module ^^, hence skipping pmv.'
+						. CLEAR . "\n";
+					$self->_set_mro_skip(FALSE);
+					return;
+				}
+			}
+		}
+	}
+	else {
+		print "min_version - $dist_min_ver\n" if ($self->{verbose} == TWO);
+		$App::Midgen::Min_Version = version->parse($dist_min_ver)->numify;
+	}
 
-	$App::Midgen::Min_Version = version->parse($dist_min_ver)->numify;
 	return;
 }
 
@@ -61,6 +115,7 @@ no Moo::Role;
 
 1;
 
+
 __END__
 
 =pod
@@ -73,7 +128,7 @@ App::Midgen::Roles::FindMinVersion - used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_11
+version: 0.31_05
 
 =head1 METHODS
 
