@@ -16,7 +16,7 @@ requires qw( format distribution_name get_module_version verbose );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_11';
+our $VERSION = '0.31_05';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -161,7 +161,8 @@ sub in_local_lib {
 	my $found_module = shift;
 
 	# exemption for perl :)
-	return $PERL_VERSION if $found_module eq 'perl';
+	# return $PERL_VERSION if $found_module eq 'perl';
+	return $] if $found_module eq 'perl';
 
 	try {
 		# Show installed version-string
@@ -192,7 +193,7 @@ App::Midgen::Role::Output - A collection of output orientated methods used by L<
 
 =head1 VERSION
 
-version: 0.29_11
+version: 0.31_05
 
 =head1 DESCRIPTION
 
