@@ -15,7 +15,7 @@ requires qw( verbose );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_11';
+our $VERSION = '0.31_05';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -64,7 +64,9 @@ sub header_eumm {
 sub body_eumm {
 	my $self         = shift;
 	my $title        = shift;
-	my $required_ref = shift;
+	my $required_ref = shift || return;
+
+	return if not %{$required_ref};
 
 	my $pm_length = 0;
 	foreach my $module_name (sort keys %{$required_ref}) {
@@ -74,14 +76,14 @@ sub body_eumm {
 	}
 
 	print THREE. "'MIN_PERL_VERSION' => '$App::Midgen::Min_Version',\n"
-		if $title eq 'requires';
+		if $title eq 'RuntimeRequires';
 
-	return if not %{$required_ref} and $title =~ m{(?:requires)\z};
+#	return if not %{$required_ref} and $title =~ m{(?:requires)\z};
 
-	if ($title eq 'requires') {
+	if ($title eq 'RuntimeRequires') {
 		print THREE. "'PREREQ_PM' => {\n";
 	}
-	elsif ($title eq 'test_requires') {
+	elsif ($title eq 'TestRequires') {
 		print THREE. "'TEST_REQUIRES' => {\n";
 	}
 	elsif ($title eq 'recommends') {
@@ -91,6 +93,10 @@ sub body_eumm {
 
 	foreach my $module_name (sort keys %{$required_ref}) {
 
+		next
+			if $title eq 'TestRequires'
+			&& $required_ref->{$module_name} =~ m/mcpan/;
+
 		my $sq_key = q{'} . $module_name . q{'};
 		printf SIX. " %-*s => '%s',\n", $pm_length + 2, $sq_key,
 			$required_ref->{$module_name};
@@ -198,7 +204,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_11
+version: 0.31_05
 
 =head1 DESCRIPTION
 
