@@ -7,7 +7,7 @@ use Moo::Role;
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_11';
+our $VERSION = '0.31_05';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -36,6 +36,9 @@ sub body_mb {
 	my $self         = shift;
 	my $title        = shift;
 	my $required_ref = shift || return;
+
+	return if not %{$required_ref};
+
 	print "\n";
 
 	my $pm_length = 0;
@@ -44,10 +47,18 @@ sub body_mb {
 			$pm_length = length $module_name;
 		}
 	}
-	print q{"} . $title . '" => {' . "\n";
+
+	$title =~ s/^RuntimeRequires/requires/;
+	$title =~ s/^TestRequires/test_requires/;
+
+	print q{"} . lc $title . '" => {' . "\n";
 
 	foreach my $module_name (sort keys %{$required_ref}) {
 
+		next
+			if $title eq 'test_requires'
+			&& $required_ref->{$module_name} =~ m/mcpan/;
+
 		my $sq_key = "\"$module_name\"";
 		printf "\t %-*s => \"%s\",\n", $pm_length + 2, $sq_key,
 			$required_ref->{$module_name};
@@ -96,7 +107,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_11
+version: 0.31_05
 
 =head1 DESCRIPTION
 
