@@ -8,7 +8,7 @@ requires qw( no_index verbose );
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_11';
+our $VERSION = '0.31_05';
 $VERSION = eval $VERSION;    ## no critic
 
 use English qw( -no_match_vars );    # Avoids reg-ex performance penalty
@@ -26,8 +26,9 @@ sub header_mi {
 	my $package_name = shift || NONE;
 	my $mi_ver       = shift || NONE;
 
-	print "\nuse inc::Module::Install::DSL "
-		. colored($mi_ver, 'yellow') . ";\n";
+	print "\nuse strict;\n";
+	print "use warnings;\n";
+	print "use inc::Module::Install " . colored($mi_ver, 'yellow') . ";\n";
 
 	if ($package_name ne NONE) {
 		$package_name =~ s{::}{-}g;
@@ -35,7 +36,8 @@ sub header_mi {
 		$package_name =~ tr{-}{/};
 		print "all_from 'lib/$package_name.pm';\n";
 	}
-	print "\n";
+
+	print BRIGHT_BLACK . "license 'perl';" . CLEAR . "\n";
 
 	return;
 }
@@ -47,6 +49,8 @@ sub body_mi {
 	my $title        = shift;
 	my $required_ref = shift || return;
 
+	return if not %{$required_ref};
+
 	my $pm_length = 0;
 	foreach my $module_name (sort keys %{$required_ref}) {
 		if (length $module_name > $pm_length) {
@@ -54,19 +58,37 @@ sub body_mi {
 		}
 	}
 
-	print "perl_version '$App::Midgen::Min_Version';\n" if $title eq 'requires';
+	print "perl_version '$App::Midgen::Min_Version';\n" if $title eq 'RuntimeRequires';
 	print "\n";
 
+	$title =~ s/^RuntimeRequires/requires/;
+	$title =~ s/^TestRequires/test_requires/;
+
 	foreach my $module_name (sort keys %{$required_ref}) {
 
+		next
+			if $title eq 'test_requires'
+			&& $required_ref->{$module_name} =~ m/mcpan/;
+
 		if ($module_name =~ /^Win32/sxm) {
 			my $sq_key = "'$module_name'";
 			printf "%s %-*s => '%s' %s;\n", $title, $pm_length + 2, $sq_key,
 				$required_ref->{$module_name}, colored('if win32', 'bright_green');
 		}
+		elsif ($module_name =~ /XS/sxm) {
+			my $sq_key = "'$module_name'";
+			printf "%s %-*s => '%s' %s;\n", $title, $pm_length + 2, $sq_key,
+				$required_ref->{$module_name}, colored('if can_xs', 'bright_blue');
+		}
+		elsif ($module_name eq 'MRO::Compat') {
+			my $sq_key = "'$module_name'";
+			printf "%s %-*s => '%s' %s;\n", $title, $pm_length + 2, $sq_key,
+				$required_ref->{$module_name},
+				colored('if $] < 5.009005', 'bright_blue');
+		}
 		else {
 			my $sq_key = "'$module_name'";
-			printf "%s %-*s => '%s';\n", $title, $pm_length + 2, $sq_key,
+			printf "%s %-*s => '%s';\n", lc $title, $pm_length + 2, $sq_key,
 				$required_ref->{$module_name};
 		}
 
@@ -137,7 +159,7 @@ used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_11
+version: 0.31_05
 
 =head1 DESCRIPTION
 
