@@ -3,13 +3,14 @@ package App::Midgen::Role::UseOk;
 use constant {BLANK => q{ }, NONE => q{}, TWO => 2, THREE => 3,};
 
 use Moo::Role;
-requires qw( ppi_document debug format xtest _process_found_modules develop );
+requires
+	qw( ppi_document debug format xtest _process_found_modules develop meta2 );
 
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.29_11';
-$VERSION = eval $VERSION; ## no critic
+our $VERSION = '0.31_05';
+$VERSION = eval $VERSION;    ## no critic
 
 use PPI;
 use Try::Tiny;
@@ -22,6 +23,7 @@ use Tie::Static qw(static);
 #######
 sub xtests_use_ok {
 	my $self = shift;
+	my $phase_relationship = shift || NONE;
 
 	#PPI::Document
 	#  PPI::Statement::Scheduled
@@ -69,7 +71,7 @@ sub xtests_use_ok {
 										foreach my $element (@{$ppi_se->{children}}) {
 
 											# some fudge to remember the module name if falied
-											static \ my $previous_module;
+											static \my $previous_module;
 											if ( $element->isa('PPI::Token::Quote::Single')
 												|| $element->isa('PPI::Token::Quote::Double'))
 											{
@@ -97,7 +99,10 @@ sub xtests_use_ok {
 												$version_string =~ s/['|"]$//;
 												next if $version_string !~ m/\A[\d|v]/;
 
-												$version_string = version::is_lax($version_string) ? $version_string : 0;
+												$version_string
+													= version::is_lax($version_string)
+													? $version_string
+													: 0;
 
 												warn 'found version_string - ' . $version_string
 													if $self->debug;
@@ -124,19 +129,11 @@ sub xtests_use_ok {
 
 	# if we found a module, process it with the correct catogery
 	if (scalar @modules > 0) {
+		$self->_process_found_modules($phase_relationship, \@modules,
+			__PACKAGE__, $phase_relationship,);
 
-		if ($self->format =~ /cpanfile|metajson|dist/) {
-			if ($self->xtest eq 'test_requires') {
-				$self->_process_found_modules('test_requires', \@modules);
-			}
-			elsif ($self->develop && $self->xtest eq 'test_develop') {
-				$self->_process_found_modules('test_develop', \@modules);
-			}
-		}
-		else {
-			$self->_process_found_modules('test_requires', \@modules);
-		}
 	}
+
 	return;
 }
 
@@ -157,7 +154,7 @@ for methods in use_ok in BEGIN blocks, used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.29_11
+version: 0.31_05
 
 =head1 METHODS
 
